# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.
from . import common_setup_methods
from . import test_point_of_sale_flow
from . import test_frontend
from . import test_point_of_sale_ui
from . import test_anglo_saxon
from . import test_point_of_sale
from . import test_pos_controller
from . import test_pos_setup
from . import test_pos_simple_orders
from . import test_pos_simple_invoiced_orders
from . import test_pos_basic_config
from . import test_pos_products_with_tax
from . import test_pos_margin
from . import test_pos_multiple_receivable_accounts
from . import test_pos_other_currency_config
from . import test_pos_with_fiscal_position
from . import test_pos_stock_account
from . import test_report_pos_order
from . import test_report_session
from . import test_res_config_settings
